@@ -26,6 +26,7 @@
 #include <QColor>
 #include <QBrush>
 #include <QWidget>
+#include <QCoreApplication>
 
 //BEGIN StateEffects
 class StateEffects
@@ -169,7 +170,7 @@ struct DecoDefaultColors {
 static const SetDefaultColors defaultViewColors = {
     { 252, 252, 252 }, // Background
     { 239, 240, 241 }, // Alternate
-    {  49,  54,  59 }, // Normal
+    {  35,  38, 39  }, // Normal
     { 127, 140, 141 }, // Inactive
     {  61, 174, 233 }, // Active
     {  41, 128, 185 }, // Link
@@ -182,7 +183,7 @@ static const SetDefaultColors defaultViewColors = {
 static const SetDefaultColors defaultWindowColors = {
     { 239, 240, 241 }, // Background
     { 189, 195, 199 }, // Alternate
-    {  49,  54,  59 }, // Normal
+    {  35,  38, 39  }, // Normal
     { 127, 140, 141 }, // Inactive
     {  61, 174, 233 }, // Active
     {  41, 128, 185 }, // Link
@@ -195,7 +196,7 @@ static const SetDefaultColors defaultWindowColors = {
 static const SetDefaultColors defaultButtonColors = {
     { 239, 240, 241 }, // Background
     { 189, 195, 199 }, // Alternate
-    {  49,  54,  59 }, // Normal
+    {  35,  38, 39  }, // Normal
     { 127, 140, 141 }, // Inactive
     {  61, 174, 233 }, // Active
     {  41, 128, 185 }, // Link
@@ -208,7 +209,7 @@ static const SetDefaultColors defaultButtonColors = {
 static const SetDefaultColors defaultSelectionColors = {
     {  61, 174, 233 }, // Background
     {  29, 153, 243 }, // Alternate
-    { 239, 240, 241 }, // Normal
+    { 252, 252, 252 }, // Normal
     { 239, 240, 241 }, // Inactive
     { 252, 252, 252 }, // Active
     { 253, 188,  75 }, // Link
@@ -219,9 +220,9 @@ static const SetDefaultColors defaultSelectionColors = {
 };
 
 static const SetDefaultColors defaultTooltipColors = {
-    {  49,  54,  59 }, // Background
+    {  35,  38, 39  }, // Background
     {  77,  77,  77 }, // Alternate
-    { 239, 240, 241 }, // Normal
+    { 252, 252, 252 }, // Normal
     { 189, 195, 199 }, // Inactive
     {  61, 174, 233 }, // Active
     {  41, 128, 185 }, // Link
@@ -231,18 +232,43 @@ static const SetDefaultColors defaultTooltipColors = {
     {  39, 174,  96 }  // Positive
 };
 
+static const SetDefaultColors defaultComplementaryColors = {
+    {  49,  54,  59 }, // Background
+    {  59,  64,  69 }, // Alternate
+    { 239, 240, 241 }, // Normal
+    { 175, 176, 179 }, // Inactive
+    { 147, 206, 233 }, // Active
+    {  61, 174, 230 }, // Link
+    {  61, 174, 230 }, // Visited
+    { 231,  76,  60 }, // Negative
+    { 253, 188,  75 }, // Neutral
+    {  46, 174, 230 }  // Positive
+};
+
 static const DecoDefaultColors defaultDecorationColors = {
     { 147, 206, 233 }, // Hover
     {  61, 174, 233 }, // Focus
 };
 //END default colors
 
+KSharedConfigPtr defaultConfig() {
+    // cache the value we'll return, since usually it's going to be the same value
+    static thread_local KSharedConfigPtr config;
+    // Read from the application's color scheme file (as set by KColorSchemeManager).
+    // If unset, this is equivalent to openConfig() and the system scheme is used.
+    const auto colorSchemePath = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
+    if (!config || config->name() != colorSchemePath) {
+        config = KSharedConfig::openConfig(colorSchemePath);
+    }
+    return config;
+}
+
 //BEGIN KColorSchemePrivate
 class KColorSchemePrivate : public QSharedData
 {
 public:
-    explicit KColorSchemePrivate(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, SetDefaultColors);
-    explicit KColorSchemePrivate(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, SetDefaultColors, const QBrush &);
+    explicit KColorSchemePrivate(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, const SetDefaultColors &);
+    explicit KColorSchemePrivate(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, const SetDefaultColors &, const QBrush &);
     ~KColorSchemePrivate() {}
 
     QBrush background(KColorScheme::BackgroundRole) const;
@@ -255,7 +281,7 @@ private:
     } _brushes;
     qreal _contrast;
 
-    void init(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, SetDefaultColors);
+    void init(const KSharedConfigPtr &, QPalette::ColorGroup, const char *, const SetDefaultColors &);
 };
 
 #define DEFAULT(c) QColor( c[0], c[1], c[2] )
@@ -265,7 +291,7 @@ private:
 KColorSchemePrivate::KColorSchemePrivate(const KSharedConfigPtr &config,
         QPalette::ColorGroup state,
         const char *group,
-        SetDefaultColors defaults)
+        const SetDefaultColors &defaults)
 {
     KConfigGroup cfg(config, group);
     _contrast = KColorScheme::contrastF(config);
@@ -281,7 +307,7 @@ KColorSchemePrivate::KColorSchemePrivate(const KSharedConfigPtr &config,
 KColorSchemePrivate::KColorSchemePrivate(const KSharedConfigPtr &config,
         QPalette::ColorGroup state,
         const char *group,
-        SetDefaultColors defaults,
+        const SetDefaultColors &defaults,
         const QBrush &tint)
 {
     KConfigGroup cfg(config, group);
@@ -302,7 +328,7 @@ KColorSchemePrivate::KColorSchemePrivate(const KSharedConfigPtr &config,
 void KColorSchemePrivate::init(const KSharedConfigPtr &config,
                                QPalette::ColorGroup state,
                                const char *group,
-                               SetDefaultColors defaults)
+                               const SetDefaultColors &defaults)
 {
     KConfigGroup cfg(config, group);
 
@@ -418,7 +444,7 @@ KColorScheme::~KColorScheme()
 KColorScheme::KColorScheme(QPalette::ColorGroup state, ColorSet set, KSharedConfigPtr config)
 {
     if (!config) {
-        config = KSharedConfig::openConfig();
+        config = defaultConfig();
     }
 
     switch (set) {
@@ -446,6 +472,9 @@ KColorScheme::KColorScheme(QPalette::ColorGroup state, ColorSet set, KSharedConf
     case Tooltip:
         d = new KColorSchemePrivate(config, state, "Colors:Tooltip", defaultTooltipColors);
         break;
+    case Complementary:
+        d = new KColorSchemePrivate(config, state, "Colors:Complementary", defaultComplementaryColors);
+        break;
     default:
         d = new KColorSchemePrivate(config, state, "Colors:View", defaultViewColors);
     }
@@ -646,7 +675,7 @@ KStatefulBrush::KStatefulBrush(KColorScheme::ColorSet set, KColorScheme::Decorat
 KStatefulBrush::KStatefulBrush(const QBrush &brush, KSharedConfigPtr config)
 {
     if (!config) {
-        config = KSharedConfig::openConfig();
+        config = defaultConfig();
     }
     d = new KStatefulBrushPrivate[3];
     d[0] = brush;
@@ -658,7 +687,7 @@ KStatefulBrush::KStatefulBrush(const QBrush &brush, const QBrush &background,
                                KSharedConfigPtr config)
 {
     if (!config) {
-        config = KSharedConfig::openConfig();
+        config = defaultConfig();
     }
     d = new KStatefulBrushPrivate[3];
     d[0] = brush;
